@@ -37,10 +37,12 @@ import WebappConfig.wrapper as wrapper
 
 from argparse             import ArgumentParser
 from WebappConfig.debug   import OUT
+from WebappConfig.eprefix import EPREFIX
 from WebappConfig.version import WCVERSION
 
 from WebappConfig.permissions import PermissionMap
 
+
 # ========================================================================
 # BashParser class
 # ------------------------------------------------------------------------
@@ -223,14 +225,14 @@ class Config:
         self.__d = {
             'config_protect'               : '',
             # Necessary to load the config file
-            'my_etcconfig'                 : '/etc/vhosts/webapp-config',
+            'my_etcconfig'                 : EPREFIX + '/etc/vhosts/webapp-config',
             'my_dotconfig'                 : '.webapp',
             'my_version'                   : WCVERSION,
             'my_conf_version'              : '7',
             'my_bugsurl'                   : wrapper.bugs_link,
             'g_myname'                     : sys.argv[0],
-            'g_orig_installdir'            : '/',
-            'g_installdir'                 : '/',
+            'g_orig_installdir'            : EPREFIX + '/',
+            'g_installdir'                 : EPREFIX + '/',
             'g_link_options'               : '',
             'g_link_type'                  : 'hard',
             'g_configprefix'               : '._cfg',
@@ -265,9 +267,9 @@ class Config:
             # -- wrobel
             'vhost_server_uid'  : 'root',
             'vhost_server_gid'  : 'root',
-            'my_persistroot'    : '/var/db/webapps',
+            'my_persistroot'    : EPREFIX + '/var/db/webapps',
             'wa_installsbase'   : 'installs',
-            'vhost_root'        : '/var/www/${vhost_hostname}',
+            'vhost_root'        : EPREFIX + '/var/www/${vhost_hostname}',
             'g_htdocsdir'       : '${vhost_root}/${my_htdocsbase}',
             'my_appdir'         : '${my_approot}/${my_appsuffix}',
             'my_htdocsdir'      : '${my_appdir}/htdocs',
@@ -277,7 +279,7 @@ class Config:
             'my_iconsdir'       : '${my_hostrootdir}/${my_iconsbase}',
             'my_errorsdir'      : '${my_hostrootdir}/${my_errorsbase}',
             'g_cgibindir'      : '${vhost_root}/${my_cgibinbase}',
-            'my_approot'        : '/usr/share/webapps',
+            'my_approot'        : EPREFIX + '/usr/share/webapps',
             'package_manager'   : 'portage',
             'allow_absolute'    : 'no',
             'my_hostrootbase'   : 'hostroot',
@@ -325,7 +327,7 @@ class Config:
         cat = self.maybe_get('cat')
         pn  = self.config.get('USER', 'pn')
         pvr = self.config.get('USER', 'pvr')
-        my_approot = self.config.get('USER', 'my_approot')
+        my_approot = os.path.normpath(self.__r + self.config.get('USER', 'my_approot'))
 
         old_layout = os.path.join(my_approot, pn, pvr)
 
@@ -996,17 +998,20 @@ class Config:
                     OUT.die('Invalid package name')
 
                 if len(args) > 1:
-                    argsvr = args[1].split('.')
-                    if len(argsvr) == 1:
-                        OUT.die('Invalid package version: %(pvr)s'
+                    pvr = args[1]
+                    has_int = False # A package version should have at least one
+                                    # numerical value, but we want to allow for
+                                    # the flexibility of having any alphanumeric
+                                    # value while checking to make sure it's sane.
+
+                    for char in pvr:
+                        if char.isdigit():
+                            has_int = True
+
+                    if not has_int:
+                        OUT.die('Invalid package version: "%(pvr)s"'
                                 % {'pvr': args[1]})
 
-                    pvr = ''
-                    for i in range(0, len(argsvr)):
-                        if not i == len(argsvr) - 1:
-                            pvr += argsvr[i] + '.'
-                        else:
-                            pvr += argsvr[i]
                     self.config.set('USER', 'pvr', pvr)
 
                 if (not options['dir'] and
@@ -1575,10 +1580,10 @@ class Config:
 
         allowed_servers = {'apache'   : WebappConfig.server.Apache,
                            'lighttpd' : WebappConfig.server.Lighttpd,
-                           'cherokee' : WebappConfig.server.Cherokee,
                            'nginx'    : WebappConfig.server.Nginx,
                            'gatling'  : WebappConfig.server.Gatling,
-                           'tracd'    : WebappConfig.server.Tracd,}
+                           'uwsgi'    : WebappConfig.server.uWSGI,
+                           'caddy'    : WebappConfig.server.Caddy, }
 
 
         server = self.config.get('USER', 'vhost_server')
