@@ -22,6 +22,7 @@
 import os, os.path
 
 from WebappConfig.debug        import OUT
+from WebappConfig.eprefix      import EPREFIX
 from WebappConfig.worker       import WebappRemove, WebappAdd
 from WebappConfig.permissions  import get_group, get_user
 
@@ -195,7 +196,7 @@ class Basic:
             dir = self.__destd
             dirs = []
 
-            while dir != '/':
+            while dir != EPREFIX + '/':
                 dirs.insert(0, dir)
                 dir = os.path.dirname(dir)
 
@@ -326,16 +327,6 @@ class Lighttpd(Basic):
         self.vhost_server_uid = get_user('lighttpd')
         self.vhost_server_gid = get_group('lighttpd')
 
-class Cherokee(Basic):
-
-    name   = 'Cherokee'
-    desc   = 'supports installation on Cherokee'
-    dep    = 'www-servers/cherokee'
-
-    def set_server_user(self):
-        self.vhost_server_uid = get_user('cherokee')
-        self.vhost_server_gid = get_group('cherokee')
-
 class Nginx(Basic):
 
     name   = 'Nginx'
@@ -356,21 +347,31 @@ class Gatling(Basic):
         self.vhost_server_uid = get_user('gatling')
         self.vhost_server_gid = get_group('gatling')
 
-class Tracd(Basic):
+class uWSGI(Basic):
 
-    name   = 'Tracd'
-    desc   = 'supports installation on Trac standalone server'
-    dep    = 'www-apps/trac'
+    name   = 'uWSGI'
+    desc   = 'supports installation on uWSGI'
+    dep    = 'www-servers/uwsgi'
 
     def set_server_user(self):
-        self.vhost_server_uid = get_user('tracd')
-        self.vhost_server_gid = get_group('tracd')
+        self.vhost_server_uid = get_user('uwsgi')
+        self.vhost_server_gid = get_group('uwsgi')
+
+class Caddy(Basic):
+
+    name   = 'Caddy'
+    desc   = 'supports installation on Caddy'
+    dep    = 'www-servers/caddy'
+
+    def set_server_user(self):
+        self.vhost_server_uid = get_user('http')
+        self.vhost_server_gid = get_group('http')
 
 def listservers():
 
     OUT.notice('\n'.join(['apache',
                           'lighttpd',
-                          'cherokee',
                           'nginx',
                           'gatling',
-                          'tracd',]))
+                          'uwsgi',
+                          'caddy',]))
